## 2.0.0a1 (2025-11-26)


### Breaking changes:

- Replace ``pkg_resources`` namespace with PEP 420 native namespace.
  Support only Plone 6.2 and Python 3.10+. #3928


### Internal:

- Expand `about` section and use the correct project board number in the PLIP issue template. @stevepiercy #22

## 1.0.1 (2025-06-19)


### Documentation:

- Fixed description in the README.  [MrTango] #20

## 1.0.0 (2025-02-06)


### Internal:

- Make final release, no changes.  [maurits] #610

## 1.0.0a1 (2024-10-31)


### New features:

- Initial release.
  [multiple Plone developers] #1


### Internal:

- Add distribution tests [@ericof] #11
- Add dependencies from Plone package [@ericof] #12

# Changelog

## 1.0a1 (unreleased)

- Initial release.
  []
